--
-- PostgreSQL database dump
--

SET client_encoding = 'UTF8';
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: prfproto; Type: DATABASE; Schema: -; Owner: prfproto_admin
--

CREATE DATABASE prfproto WITH TEMPLATE = template0 ENCODING = 'UTF8';


ALTER DATABASE prfproto OWNER TO prfproto_admin;

\connect prfproto

SET client_encoding = 'UTF8';
SET check_function_bodies = false;
SET client_min_messages = warning;

--
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: prfproto_admin
--

COMMENT ON SCHEMA public IS 'Standard public schema';


SET search_path = public, pg_catalog;

--
-- Name: dokumente_id_seq; Type: SEQUENCE; Schema: public; Owner: thomas
--

CREATE SEQUENCE dokumente_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.dokumente_id_seq OWNER TO thomas;

SET default_tablespace = '';

SET default_with_oids = true;

--
-- Name: dokumente; Type: TABLE; Schema: public; Owner: thomas; Tablespace: 
--

CREATE TABLE dokumente (
    id integer DEFAULT nextval('dokumente_id_seq'::regclass),
    beschreibung text NOT NULL,
    seiten integer NOT NULL,
    defaultid integer DEFAULT 2222
);


ALTER TABLE public.dokumente OWNER TO thomas;

--
-- Name: TABLE dokumente; Type: COMMENT; Schema: public; Owner: thomas
--

COMMENT ON TABLE dokumente IS 'Enthaelt Dokumente die fuer die Sprechstunde wichtig sind, aber nicht Protokolle oder Klausuren sind.';


SET default_with_oids = false;

--
-- Name: druckermapping; Type: TABLE; Schema: public; Owner: thomas; Tablespace: 
--

CREATE TABLE druckermapping (
    uid integer NOT NULL,
    druckeraccount integer NOT NULL
);


ALTER TABLE public.druckermapping OWNER TO thomas;

--
-- Name: fehlkopien_id_seq; Type: SEQUENCE; Schema: public; Owner: thomas
--

CREATE SEQUENCE fehlkopien_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.fehlkopien_id_seq OWNER TO thomas;

SET default_with_oids = true;

--
-- Name: fehlkopien; Type: TABLE; Schema: public; Owner: thomas; Tablespace: 
--

CREATE TABLE fehlkopien (
    id integer DEFAULT nextval('fehlkopien_id_seq'::regclass) NOT NULL,
    vonaccount integer NOT NULL,
    nachaccount integer NOT NULL,
    seiten integer NOT NULL,
    datum timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.fehlkopien OWNER TO thomas;

SET default_with_oids = false;

--
-- Name: gebiet; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE gebiet (
    id bigserial NOT NULL,
    vertiefungsgebiet text NOT NULL
);


ALTER TABLE public.gebiet OWNER TO prfproto_admin;

--
-- Name: TABLE gebiet; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE gebiet IS 'Zuordnung gebietID -> Vertiefungsgebiet / VD-Fach / etc';


--
-- Name: hilfszaehler; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE hilfszaehler (
    beschreibung text NOT NULL,
    wert bigint NOT NULL
);


ALTER TABLE public.hilfszaehler OWNER TO prfproto_admin;

--
-- Name: TABLE hilfszaehler; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE hilfszaehler IS 'Hilft Zählen wo immer nötig.';


--
-- Name: klausuren; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE klausuren (
    id bigserial NOT NULL,
    vorlesung text,
    prof text,
    datum date,
    kommentar text,
    bestand integer DEFAULT 0,
    sollbestand integer DEFAULT 0,
    gueltigbis date,
    seiten integer,
    verkauft bigint DEFAULT 0,
    veraltet boolean
);


ALTER TABLE public.klausuren OWNER TO prfproto_admin;

SET default_with_oids = true;

--
-- Name: klausurenlog; Type: TABLE; Schema: public; Owner: thomas; Tablespace: 
--

CREATE TABLE klausurenlog (
    value integer NOT NULL,
    klausur bigint NOT NULL,
    datum timestamp(6) with time zone DEFAULT now() NOT NULL
);


ALTER TABLE public.klausurenlog OWNER TO thomas;

SET default_with_oids = false;

--
-- Name: ordner; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE ordner (
    id bigserial NOT NULL,
    name text,
    verleihbar boolean DEFAULT true NOT NULL,
    ausleihername text,
    ausleihertelefon text,
    ausleiheremail text,
    verliehen boolean DEFAULT false NOT NULL,
    verleihdatum date DEFAULT '2006-05-15'::date,
    ordnerpfand integer DEFAULT 5 NOT NULL,
    protokollpfand integer DEFAULT 5 NOT NULL
);


ALTER TABLE public.ordner OWNER TO prfproto_admin;

--
-- Name: TABLE ordner; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE ordner IS 'Existierende Ordner';


--
-- Name: protokolle; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE protokolle (
    id bigserial NOT NULL,
    gebiet bigint NOT NULL,
    datum date NOT NULL,
    seiten bigint NOT NULL
);


ALTER TABLE public.protokolle OWNER TO prfproto_admin;

--
-- Name: TABLE protokolle; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE protokolle IS 'Zentrale Prüfungsprotkollstelle';


--
-- Name: protokollpfand; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE protokollpfand (
    id bigserial NOT NULL,
    name text NOT NULL,
    ordner1 bigint,
    ordner2 bigint,
    ordner3 bigint,
    betrag bigint,
    datum timestamp with time zone DEFAULT ('now'::text)::timestamp without time zone
);


ALTER TABLE public.protokollpfand OWNER TO prfproto_admin;

--
-- Name: TABLE protokollpfand; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE protokollpfand IS 'Wer bekommt noch?';


--
-- Name: protokollpfand_log; Type: TABLE; Schema: public; Owner: postgres; Tablespace: 
--

CREATE TABLE protokollpfand_log (
    log_id serial NOT NULL,
    "time" timestamp without time zone DEFAULT now(),
    wert integer
);


ALTER TABLE public.protokollpfand_log OWNER TO postgres;

--
-- Name: pruefer; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE pruefer (
    id bigserial NOT NULL,
    pruefername text NOT NULL
);


ALTER TABLE public.pruefer OWNER TO prfproto_admin;

--
-- Name: TABLE pruefer; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE pruefer IS 'Zuordnung PrueferID -> Name';


--
-- Name: pruefungpruefer; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE pruefungpruefer (
    protokollid bigint NOT NULL,
    prueferid bigint NOT NULL
);


ALTER TABLE public.pruefungpruefer OWNER TO prfproto_admin;

--
-- Name: TABLE pruefungpruefer; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE pruefungpruefer IS 'Ordnet Protkollen Prüfer zu';


--
-- Name: pruefungvorlesung; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE pruefungvorlesung (
    protokollid bigint NOT NULL,
    vorlesungsid bigint NOT NULL,
    dozent text
);


ALTER TABLE public.pruefungvorlesung OWNER TO prfproto_admin;

--
-- Name: TABLE pruefungvorlesung; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE pruefungvorlesung IS 'Ordnet Protkollen Vorlesungen zu';


--
-- Name: snackkonten; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE snackkonten (
    kontostand numeric(8,2) DEFAULT 0,
    uid integer NOT NULL,
    name text
);


ALTER TABLE public.snackkonten OWNER TO prfproto_admin;

--
-- Name: TABLE snackkonten; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE snackkonten IS 'Kontoverwaltung für Snacks und Getränke - Strichlistenersatz';


--
-- Name: snacklog; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE snacklog (
    value numeric(8,2) NOT NULL,
    datum timestamp with time zone DEFAULT now() NOT NULL,
    uid integer NOT NULL
);


ALTER TABLE public.snacklog OWNER TO prfproto_admin;

--
-- Name: TABLE snacklog; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE snacklog IS 'führt Log über Einnahmnen und Ausgaben der Snackkasse';


--
-- Name: snacks; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE snacks (
    barcode bigint NOT NULL,
    bezeichnung text,
    preis numeric(8,2) NOT NULL
);


ALTER TABLE public.snacks OWNER TO prfproto_admin;

--
-- Name: TABLE snacks; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE snacks IS 'Info zu verkaufbaren Snacks und Getränken';


SET default_with_oids = true;

--
-- Name: spenden; Type: TABLE; Schema: public; Owner: thomas; Tablespace: 
--

CREATE TABLE spenden (
    uid integer NOT NULL,
    art integer NOT NULL,
    value numeric(8,2) DEFAULT 0::numeric
);


ALTER TABLE public.spenden OWNER TO thomas;

SET default_with_oids = false;

--
-- Name: vorbestellung; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE vorbestellung (
    id bigint NOT NULL,
    protokollid bigint NOT NULL,
    datum date DEFAULT '2006-05-15'::date NOT NULL
);


ALTER TABLE public.vorbestellung OWNER TO prfproto_admin;

--
-- Name: TABLE vorbestellung; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE vorbestellung IS 'Nimm Vorbestellungen entgegen, die dann nur noch gedruckt werden.';


--
-- Name: vorbestellung_id_seq; Type: SEQUENCE; Schema: public; Owner: prfproto_admin
--

CREATE SEQUENCE vorbestellung_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


ALTER TABLE public.vorbestellung_id_seq OWNER TO prfproto_admin;

--
-- Name: vorlesungen; Type: TABLE; Schema: public; Owner: prfproto_admin; Tablespace: 
--

CREATE TABLE vorlesungen (
    id bigserial NOT NULL,
    vorlesung text NOT NULL
);


ALTER TABLE public.vorlesungen OWNER TO prfproto_admin;

--
-- Name: TABLE vorlesungen; Type: COMMENT; Schema: public; Owner: prfproto_admin
--

COMMENT ON TABLE vorlesungen IS 'VorlesungsID -> Vorlesung';


--
-- Name: gebiet_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY gebiet
    ADD CONSTRAINT gebiet_pkey PRIMARY KEY (id);


--
-- Name: hilfszaehler_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY hilfszaehler
    ADD CONSTRAINT hilfszaehler_pkey PRIMARY KEY (beschreibung);


--
-- Name: klausuren_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY klausuren
    ADD CONSTRAINT klausuren_pkey PRIMARY KEY (id);


--
-- Name: ordner_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY ordner
    ADD CONSTRAINT ordner_pkey PRIMARY KEY (id);


--
-- Name: pk_fehlkopien; Type: CONSTRAINT; Schema: public; Owner: thomas; Tablespace: 
--

ALTER TABLE ONLY fehlkopien
    ADD CONSTRAINT pk_fehlkopien PRIMARY KEY (id);


--
-- Name: pk_spenden; Type: CONSTRAINT; Schema: public; Owner: thomas; Tablespace: 
--

ALTER TABLE ONLY spenden
    ADD CONSTRAINT pk_spenden PRIMARY KEY (uid, art);


--
-- Name: protokolle_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY protokolle
    ADD CONSTRAINT protokolle_pkey PRIMARY KEY (id);


--
-- Name: protokollpfand_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY protokollpfand
    ADD CONSTRAINT protokollpfand_pkey PRIMARY KEY (id);


--
-- Name: pruefer_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY pruefer
    ADD CONSTRAINT pruefer_pkey PRIMARY KEY (id);


--
-- Name: snackkonten_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY snackkonten
    ADD CONSTRAINT snackkonten_pkey PRIMARY KEY (uid);


--
-- Name: snacks_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY snacks
    ADD CONSTRAINT snacks_pkey PRIMARY KEY (barcode);


--
-- Name: vorlesungen_pkey; Type: CONSTRAINT; Schema: public; Owner: prfproto_admin; Tablespace: 
--

ALTER TABLE ONLY vorlesungen
    ADD CONSTRAINT vorlesungen_pkey PRIMARY KEY (id);


--
-- Name: klausurenlog; Type: RULE; Schema: public; Owner: prfproto_admin
--

CREATE RULE klausurenlog AS ON UPDATE TO klausuren WHERE (new.verkauft <> old.verkauft) DO INSERT INTO klausurenlog (value, klausur) VALUES (new.seiten, new.id);


--
-- Name: log_pfand_ausgabe; Type: RULE; Schema: public; Owner: prfproto_admin
--

CREATE RULE log_pfand_ausgabe AS ON DELETE TO protokollpfand DO INSERT INTO protokollpfand_log (wert) VALUES ((- old.betrag));


--
-- Name: log_pfand_einnahme; Type: RULE; Schema: public; Owner: prfproto_admin
--

CREATE RULE log_pfand_einnahme AS ON INSERT TO protokollpfand DO INSERT INTO protokollpfand_log (wert) VALUES (new.betrag);


--
-- Name: snacklog_rule; Type: RULE; Schema: public; Owner: prfproto_admin
--

CREATE RULE snacklog_rule AS ON UPDATE TO snackkonten WHERE (new.kontostand <> old.kontostand) DO INSERT INTO snacklog (uid, value) VALUES (new.uid, (new.kontostand - old.kontostand));


--
-- Name: protokolle_gebiet_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY protokolle
    ADD CONSTRAINT protokolle_gebiet_fkey FOREIGN KEY (gebiet) REFERENCES gebiet(id);


--
-- Name: protokollpfand_ordner1_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY protokollpfand
    ADD CONSTRAINT protokollpfand_ordner1_fkey FOREIGN KEY (ordner1) REFERENCES ordner(id);


--
-- Name: protokollpfand_ordner2_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY protokollpfand
    ADD CONSTRAINT protokollpfand_ordner2_fkey FOREIGN KEY (ordner2) REFERENCES ordner(id);


--
-- Name: protokollpfand_ordner3_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY protokollpfand
    ADD CONSTRAINT protokollpfand_ordner3_fkey FOREIGN KEY (ordner3) REFERENCES ordner(id);


--
-- Name: pruefungpruefer_protokollid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY pruefungpruefer
    ADD CONSTRAINT pruefungpruefer_protokollid_fkey FOREIGN KEY (protokollid) REFERENCES protokolle(id);


--
-- Name: pruefungpruefer_prueferid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY pruefungpruefer
    ADD CONSTRAINT pruefungpruefer_prueferid_fkey FOREIGN KEY (prueferid) REFERENCES pruefer(id);


--
-- Name: pruefungvorlesung_protokollid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY pruefungvorlesung
    ADD CONSTRAINT pruefungvorlesung_protokollid_fkey FOREIGN KEY (protokollid) REFERENCES protokolle(id);


--
-- Name: pruefungvorlesung_vorlesungsid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY pruefungvorlesung
    ADD CONSTRAINT pruefungvorlesung_vorlesungsid_fkey FOREIGN KEY (vorlesungsid) REFERENCES vorlesungen(id);


--
-- Name: vorbestellung_protokollid_fkey; Type: FK CONSTRAINT; Schema: public; Owner: prfproto_admin
--

ALTER TABLE ONLY vorbestellung
    ADD CONSTRAINT vorbestellung_protokollid_fkey FOREIGN KEY (protokollid) REFERENCES protokolle(id);


--
-- Name: public; Type: ACL; Schema: -; Owner: prfproto_admin
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM prfproto_admin;
GRANT ALL ON SCHEMA public TO prfproto_admin;
GRANT USAGE ON SCHEMA public TO PUBLIC;


--
-- Name: dokumente_id_seq; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE dokumente_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE dokumente_id_seq FROM thomas;
GRANT ALL ON TABLE dokumente_id_seq TO thomas;
GRANT ALL ON TABLE dokumente_id_seq TO prfproto;
GRANT ALL ON TABLE dokumente_id_seq TO prfproto_admin;


--
-- Name: dokumente; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE dokumente FROM PUBLIC;
REVOKE ALL ON TABLE dokumente FROM thomas;
GRANT ALL ON TABLE dokumente TO thomas;
GRANT ALL ON TABLE dokumente TO prfproto;
GRANT ALL ON TABLE dokumente TO prfproto_admin;


--
-- Name: druckermapping; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE druckermapping FROM PUBLIC;
REVOKE ALL ON TABLE druckermapping FROM thomas;
GRANT ALL ON TABLE druckermapping TO thomas;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE druckermapping TO prfproto_admin;
GRANT SELECT ON TABLE druckermapping TO prfproto;


--
-- Name: fehlkopien_id_seq; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE fehlkopien_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE fehlkopien_id_seq FROM thomas;
GRANT ALL ON TABLE fehlkopien_id_seq TO thomas;
GRANT ALL ON TABLE fehlkopien_id_seq TO prfproto;
GRANT ALL ON TABLE fehlkopien_id_seq TO prfproto_admin;


--
-- Name: fehlkopien; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE fehlkopien FROM PUBLIC;
REVOKE ALL ON TABLE fehlkopien FROM thomas;
GRANT ALL ON TABLE fehlkopien TO thomas;
GRANT ALL ON TABLE fehlkopien TO prfproto;
GRANT ALL ON TABLE fehlkopien TO prfproto_admin;


--
-- Name: gebiet; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE gebiet FROM PUBLIC;
REVOKE ALL ON TABLE gebiet FROM prfproto_admin;
GRANT ALL ON TABLE gebiet TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE gebiet TO prfproto;
GRANT SELECT ON TABLE gebiet TO prfproto_luser;


--
-- Name: gebiet_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE gebiet_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE gebiet_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE gebiet_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE gebiet_id_seq TO prfproto;


--
-- Name: hilfszaehler; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE hilfszaehler FROM PUBLIC;
REVOKE ALL ON TABLE hilfszaehler FROM prfproto_admin;
GRANT ALL ON TABLE hilfszaehler TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE hilfszaehler TO prfproto;


--
-- Name: klausuren; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE klausuren FROM PUBLIC;
REVOKE ALL ON TABLE klausuren FROM prfproto_admin;
GRANT ALL ON TABLE klausuren TO prfproto_admin;
GRANT ALL ON TABLE klausuren TO prfproto;


--
-- Name: klausuren_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE klausuren_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE klausuren_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE klausuren_id_seq TO prfproto_admin;
GRANT ALL ON TABLE klausuren_id_seq TO prfproto;


--
-- Name: klausurenlog; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE klausurenlog FROM PUBLIC;
REVOKE ALL ON TABLE klausurenlog FROM thomas;
GRANT ALL ON TABLE klausurenlog TO thomas;
GRANT SELECT ON TABLE klausurenlog TO prfproto;


--
-- Name: ordner; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE ordner FROM PUBLIC;
REVOKE ALL ON TABLE ordner FROM prfproto_admin;
GRANT ALL ON TABLE ordner TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE ordner TO prfproto;


--
-- Name: ordner_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE ordner_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE ordner_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE ordner_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE ordner_id_seq TO prfproto;


--
-- Name: protokolle; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE protokolle FROM PUBLIC;
REVOKE ALL ON TABLE protokolle FROM prfproto_admin;
GRANT ALL ON TABLE protokolle TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE protokolle TO prfproto;
GRANT SELECT ON TABLE protokolle TO prfproto_luser;


--
-- Name: protokolle_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE protokolle_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE protokolle_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE protokolle_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE protokolle_id_seq TO prfproto;


--
-- Name: protokollpfand; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE protokollpfand FROM PUBLIC;
REVOKE ALL ON TABLE protokollpfand FROM prfproto_admin;
GRANT ALL ON TABLE protokollpfand TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE protokollpfand TO prfproto;


--
-- Name: protokollpfand_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE protokollpfand_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE protokollpfand_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE protokollpfand_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE protokollpfand_id_seq TO prfproto;


--
-- Name: protokollpfand_log; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE protokollpfand_log FROM PUBLIC;
REVOKE ALL ON TABLE protokollpfand_log FROM postgres;
GRANT ALL ON TABLE protokollpfand_log TO postgres;
GRANT SELECT ON TABLE protokollpfand_log TO prfproto;


--
-- Name: protokollpfand_log_log_id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE protokollpfand_log_log_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE protokollpfand_log_log_id_seq FROM postgres;
GRANT ALL ON TABLE protokollpfand_log_log_id_seq TO postgres;
GRANT ALL ON TABLE protokollpfand_log_log_id_seq TO prfproto;


--
-- Name: pruefer; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE pruefer FROM PUBLIC;
REVOKE ALL ON TABLE pruefer FROM prfproto_admin;
GRANT ALL ON TABLE pruefer TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE pruefer TO prfproto;
GRANT SELECT ON TABLE pruefer TO prfproto_luser;


--
-- Name: pruefer_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE pruefer_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE pruefer_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE pruefer_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE pruefer_id_seq TO prfproto;


--
-- Name: pruefungpruefer; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE pruefungpruefer FROM PUBLIC;
REVOKE ALL ON TABLE pruefungpruefer FROM prfproto_admin;
GRANT ALL ON TABLE pruefungpruefer TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE pruefungpruefer TO prfproto;
GRANT SELECT ON TABLE pruefungpruefer TO prfproto_luser;


--
-- Name: pruefungvorlesung; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE pruefungvorlesung FROM PUBLIC;
REVOKE ALL ON TABLE pruefungvorlesung FROM prfproto_admin;
GRANT ALL ON TABLE pruefungvorlesung TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE pruefungvorlesung TO prfproto;
GRANT SELECT ON TABLE pruefungvorlesung TO prfproto_luser;


--
-- Name: snackkonten; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE snackkonten FROM PUBLIC;
REVOKE ALL ON TABLE snackkonten FROM prfproto_admin;
GRANT ALL ON TABLE snackkonten TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE ON TABLE snackkonten TO prfproto;


--
-- Name: snacklog; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE snacklog FROM PUBLIC;
REVOKE ALL ON TABLE snacklog FROM prfproto_admin;
GRANT ALL ON TABLE snacklog TO prfproto_admin;
GRANT SELECT ON TABLE snacklog TO prfproto;


--
-- Name: snacks; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE snacks FROM PUBLIC;
REVOKE ALL ON TABLE snacks FROM prfproto_admin;
GRANT ALL ON TABLE snacks TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE snacks TO prfproto;


--
-- Name: spenden; Type: ACL; Schema: public; Owner: thomas
--

REVOKE ALL ON TABLE spenden FROM PUBLIC;
REVOKE ALL ON TABLE spenden FROM thomas;
GRANT ALL ON TABLE spenden TO thomas;
GRANT ALL ON TABLE spenden TO prfproto;
GRANT ALL ON TABLE spenden TO prfproto_admin;


--
-- Name: vorbestellung; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE vorbestellung FROM PUBLIC;
REVOKE ALL ON TABLE vorbestellung FROM prfproto_admin;
GRANT ALL ON TABLE vorbestellung TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE vorbestellung TO prfproto;
GRANT INSERT ON TABLE vorbestellung TO prfproto_luser;


--
-- Name: vorbestellung_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE vorbestellung_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE vorbestellung_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE vorbestellung_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE vorbestellung_id_seq TO prfproto;
GRANT UPDATE ON TABLE vorbestellung_id_seq TO prfproto_luser;


--
-- Name: vorlesungen; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE vorlesungen FROM PUBLIC;
REVOKE ALL ON TABLE vorlesungen FROM prfproto_admin;
GRANT ALL ON TABLE vorlesungen TO prfproto_admin;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE vorlesungen TO prfproto;
GRANT SELECT ON TABLE vorlesungen TO prfproto_luser;


--
-- Name: vorlesungen_id_seq; Type: ACL; Schema: public; Owner: prfproto_admin
--

REVOKE ALL ON TABLE vorlesungen_id_seq FROM PUBLIC;
REVOKE ALL ON TABLE vorlesungen_id_seq FROM prfproto_admin;
GRANT ALL ON TABLE vorlesungen_id_seq TO prfproto_admin;
GRANT SELECT,UPDATE ON TABLE vorlesungen_id_seq TO prfproto;


--
-- PostgreSQL database dump complete
--

